Introduction
============

Welcome to ``pydoctor``'s documentation!

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   quickstart
   codedoc
   docformat/index
   sphinx-integration
   customize
   help
   faq
   transition
   contrib
   readme

.. toctree::
   :maxdepth: 1
   :caption: Quick links

   api/index
   GitHub <https://github.com/twisted/pydoctor>
   PyPI <https://pypi.org/project/pydoctor>
